@@ -1,9 +1,11 @@
 <?php
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (ADMIN_LEVEL);
+Assets_Page::header (gettext ("Administration"));
 $smarty = new Smarty_Bibledit (__FILE__);
 $plugin_enumerator = Plugins_Enumerator::getInstance();
 $plugins = $plugin_enumerator->getMenuPlugins ("administration");
 $smarty->assign ("plugins", $plugins);
 $smarty->display("index.tpl");
+Assets_Page::footer ();
 ?>
