@@ -110,6 +110,18 @@ class Notes_Editor
     $database_sessions->setEditConsultationNoteView ($editconsultationnoteview);
     $database_sessions->setBulkUpdateConsultationNotes ($bulkupdateconsultationnotes);
     
+    // When a note is opened, then the passage navigator should go to the passage that belongs to that note.
+    if (isset ($_GET['consultationnote'])) {
+      // Variable $consultationnote has been set above. It contains the note identifier.
+      $passages = $database_notes->getPassages ($consultationnote);
+      if (is_array ($passages)) {
+        if (!empty ($passages)) {
+          $ipc_focus = Ipc_Focus::getInstance();
+          $ipc_focus->set ($passages[0][0], $passages[0][1], $passages[0][2]);
+        }
+      }
+    }
+    
     // Save new note.
     if (isset ($_GET['savenewconsultationnote'])) {
       if (isset($_POST['submit'])) {
@@ -137,7 +149,20 @@ class Notes_Editor
         }
       }
     }
-   
+
+    // Edit summary.
+    @$consultationnoteeditsummary = $_GET['consultationnoteeditsummary'];
+    if (isset ($consultationnoteeditsummary)) {
+      $dialog_entry = new Dialog_Entry (array ("session" => $database_sessions->getCurrentSessionId ()), gettext ("Please enter the summary"), $database_notes->getSummary ($consultationnote), "consultationnoteeditsummary", "");
+      die;
+    }
+    @$consultationnoteeditsummary = $_POST['consultationnoteeditsummary'];
+    if (isset ($consultationnoteeditsummary)) {
+      $summary = $_POST['entry'];
+      $database_notes->setSummary ($consultationnote, $summary);
+      // $notes_logic->handlerUpdateNote ($consultationnote);
+    }
+
     // Delete a note.
     @$deleteconsultationnote = $_GET['deleteconsultationnote'];
     if (isset ($deleteconsultationnote)) {
@@ -172,8 +197,9 @@ class Notes_Editor
         $dialog_list->run();
       } else {
         if ($database_users->usernameExists ($addassignee)) {
+          // Assign logic comes first.
+          $notes_logic->handlerAssignNote ($consultationnote, $addassignee);
           $database_notes->assignUser ($consultationnote, $addassignee);
-          $notes_logic->handlerUpdateNote ($consultationnote);
         }
       }
     }
@@ -182,13 +208,13 @@ class Notes_Editor
     @$removeassignee = $_GET['consultationnoteremoveassignee'];
     if (isset ($removeassignee)) {
       $database_notes->unassignUser ($consultationnote, $removeassignee);
-      $notes_logic->handlerUpdateNote ($consultationnote);
+      // $notes_logic->handlerUpdateNote ($consultationnote);
     }
     @$unassignme = $_GET['consultationnoteunassignme'];
     if (isset ($unassignme)) {
       // If a user unassigns himself, the automatic assignment setting should not assign him again.
       // For that reason the assignment logic is done before the user is unasssigned.
-      $notes_logic->handlerUpdateNote ($consultationnote);
+      // $notes_logic->handlerUpdateNote ($consultationnote);
       $database_notes->unassign ($consultationnote);
     }
 
@@ -207,7 +233,7 @@ class Notes_Editor
       } else {
         if ($consultationnotebible == "0gen0bible0") $consultationnotebible = "";
         $database_notes->setBible ($consultationnote, $consultationnotebible);
-        $notes_logic->handlerUpdateNote ($consultationnote);
+        // $notes_logic->handlerUpdateNote ($consultationnote);
       }
     }
 
@@ -223,7 +249,7 @@ class Notes_Editor
         $dialog_list->run();
       } else {
         $database_notes->setStatus ($consultationnote, $consultationnotestatus);
-        $notes_logic->handlerUpdateNote ($consultationnote);
+        // $notes_logic->handlerUpdateNote ($consultationnote);
       }
     }
 
@@ -239,7 +265,7 @@ class Notes_Editor
         $dialog_list->run();
       } else {
         $database_notes->setRawSeverity ($consultationnote, $consultationnoteseverity);
-        $notes_logic->handlerUpdateNote ($consultationnote);
+        // $notes_logic->handlerUpdateNote ($consultationnote);
       }
     }
 
@@ -256,7 +282,7 @@ class Notes_Editor
         $dialog_list->run();
       } else {
         $database_notes->setPrivacy ($consultationnote, $consultationnoteprivacy);
-        $notes_logic->handlerUpdateNote ($consultationnote);
+        // $notes_logic->handlerUpdateNote ($consultationnote);
       }
     }
 
@@ -280,7 +306,7 @@ class Notes_Editor
           }
         }
         $database_notes->setPassages ($consultationnote, $passages);
-        $notes_logic->handlerUpdateNote ($consultationnote);
+        // $notes_logic->handlerUpdateNote ($consultationnote);
       }
     }
     
@@ -393,8 +419,9 @@ class Notes_Editor
           if ($database_users->usernameExists ($assignee)) {
             foreach ($identifiers as $identifier) {
               if (!$database_notes->isAssigned ($identifier, $assignee)) {
+                // Assign logic comes first.
+                $notes_logic->handlerAssignNote ($identifier, $assignee);
                 $database_notes->assignUser ($identifier, $assignee);
-                $notes_logic->handlerUpdateNote ($identifier);
               }
             }
           }
@@ -418,7 +445,7 @@ class Notes_Editor
             foreach ($identifiers as $identifier) {
               if ($database_notes->isAssigned ($identifier, $assignee)) {
                 $database_notes->unassignUser ($identifier, $assignee);
-                $notes_logic->handlerUpdateNote ($identifier);
+                // $notes_logic->handlerUpdateNote ($identifier);
               }
             }
           }
@@ -440,7 +467,7 @@ class Notes_Editor
           foreach ($identifiers as $identifier) {
             if ($database_notes->getRawStatus ($identifier) != $status) {
               $database_notes->setStatus ($identifier, $status);
-              $notes_logic->handlerUpdateNote ($identifier);
+              // $notes_logic->handlerUpdateNote ($identifier);
             }
           }
           Assets_Page::success (gettext ("The status of the notes was updated"));
@@ -461,7 +488,7 @@ class Notes_Editor
           foreach ($identifiers as $identifier) {
             if ($database_notes->getRawSeverity ($identifier) != $severity) {
               $database_notes->setRawSeverity ($identifier, $severity);
-              $notes_logic->handlerUpdateNote ($identifier);
+              // $notes_logic->handlerUpdateNote ($identifier);
             }
           }
           Assets_Page::success (gettext ("The severity of the notes was updated"));
@@ -483,7 +510,7 @@ class Notes_Editor
           foreach ($identifiers as $identifier) {
             if ($database_notes->getPrivacy ($identifier) != $visibility) {
               $database_notes->setPrivacy ($identifier, $visibility);
-              $notes_logic->handlerUpdateNote ($identifier);
+              // $notes_logic->handlerUpdateNote ($identifier);
             }
           }
           Assets_Page::success (gettext ("The visibility of the notes was updated"));
@@ -507,13 +534,26 @@ class Notes_Editor
           foreach ($identifiers as $identifier) {
             if ($database_notes->getBible ($identifier) != $bible) {
               $database_notes->setBible ($identifier, $bible);
-              $notes_logic->handlerUpdateNote ($identifier);
+              // $notes_logic->handlerUpdateNote ($identifier);
             }
           }
           Assets_Page::success (gettext ("The Bible of the notes was updated"));
           $database_logs->log ("Bible update of notes: $identifierlist", true);
         }
       }
+      // Bulk note delete.
+      if ($bulk_update == "delete") {
+        if ($_GET['confirm'] != "yes") {
+          $dialog_yes = new Dialog_Yes2 (gettext ("Would you like to delete the notes?"), "&consultationnotesbulkupdate=delete");
+        } else {
+          foreach ($identifiers as $identifier) {
+            $notes_logic->handlerDeleteNote ($identifier); // Notifications handling.
+            $database_notes->delete ($identifier);
+          }
+          Assets_Page::success (gettext ("The notes were deleted"));
+          $database_logs->log ("Notes deleted: $identifierlist", true);
+        }
+      }
     }
   }
   
